JobcelisException class

Exception thrown when the Jobcelis API returns an error response.

Implemented types

Constructors

JobcelisException(int statusCode, String detail)
Creates a new JobcelisException with the given statusCode and detail.

Properties

detail String
Error detail from the API response.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP status code returned by the API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited